import request from '@/utils/request'
/**
 * 获取商品列表(过滤)
 * @param {*} id 专区ID
 * @param {*} productId 商品ID
 * @param {*} shopName 供应商名称
 * @param {*} productName 商品名称
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function selectProductList(params) {
  return request({
    url: '/page/selectProductList',
    method: 'get',
    params
  })
}
/**
 * 获取推荐商品列表(过滤)
 * @param {*} id 专区ID
 * @param {*} productId 商品ID
 * @param {*} shopName 供应商名称
 * @param {*} productName 商品名称
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function recommendProductList(params) {
  return request({
    url: '/page/select/recommendProductList',
    method: 'get',
    params
  })
}
/**
 * 获取首页专区列表
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function getPageZoneList(params) {
  return request({
    url: '/page/zoneList',
    method: 'get',
    params
  })
}
/**
 * 首页专区保存
 * @param {*} id 专区Id
 * @param {*} floorTitle 专区标题
 * @param {*} floorDetail 专区描述
 * @param {*} sort 排序
 * @param {*} wwwEnabledStatus Pc端状态 0停用 1启用
 * @param {*} crmEnabledStatus CRM端状态 0停用 1启用
 * @param {*} createBy 操作人
 * @returns
 */
export function savePageZone(data) {
  return request({
    url: '/page/saveZone',
    method: 'post',
    data: data
  })
}
/**
 * 删除专区
 * @param {*} id 专区Id
 * @returns
 */
export function delPageZone(params) {
  return request({
    url: '/page/delZone/',
    method: 'get',
    params
  })
}
/**
 * 更新专区状态
 * @param {*} id 专区Id
 * @param {*} status 0停用 1启用
 * @param {*} type  0www 1小程序
 * @returns
 */
export function updateZoneStatus(params) {
  return request({
    url: '/page/updateEnabledStatus',
    method: 'get',
    params
  })
}
/**
/**
 * 更新专区排序
 * @param {*} id 专区Id
 * @param {*} sort 排序值
 * @returns
 */
export function updateZoneSort(params) {
  return request({
    url: '/page/updateSort',
    method: 'get',
    params
  })
}

/**
 * 获取专区商品列表
 * @param {*} id 专区Id
 * @param {*} productId 商品Id
 * @param {*} shopName 供应商名称
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function getZoneProductList(params) {
  return request({
    url: '/page/zoneProductList',
    method: 'get',
    params
  })
}
/**
 * 删除专区商品
 * @param {*} id 专区Id
 * @param {*} ids 商品Id逗号拼接
 * @returns
 */
export function delZoneProduct(params) {
  return request({
    url: '/page/delZoneProduct',
    method: 'get',
    params
  })
}
/**
 * 保存专区商品
 * @param {*} id 专区Id
 * @param {*} ids 商品Id逗号拼接
 * @returns
 */
export function addZoneProduct(params) {
  return request({
    url: '/page/addZoneProduct',
    method: 'get',
    params
  })
}
/**
 * 专区商品排序
 * @param {*} id 专区Id
 * @param {*} productId 商品Id
 * @param {*} sort 排序值
 * @returns
 */
export function updateProductSort(params) {
  return request({
    url: '/page/updateProductSort',
    method: 'get',
    params
  })
}
/**
 * 获取专区轮播图列表
 * @param {*} id 专区Id
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function getZoneImageList(params) {
  return request({
    url: '/page/zoneImageList',
    method: 'get',
    params
  })
}
/**
 * 专区轮播图保存
 * @param {*} zoneId 专区Id
 * @param {*} imageId 轮播图Id
 * @param {*} title 专区标题
 * @param {*} image WWW图片
 * @param {*} crmImage 小程序图片
 * @param {*} link WWW跳转链接
 * @param {*} crmLink 小程序跳转链接
 * @param {*} wwwEnabledStatus Pc端状态 0停用 1启用
 * @param {*} crmEnabledStatus 小程序端状态 0停用 1启用
 * @param {*} sort 排序
 * @returns
 */
export function saveZoneImage(data) {
  return request({
    url: '/page/saveZoneImage',
    method: 'post',
    data: data
  })
}
/**
 * 删除专区轮播
 * @param {*} imageId 轮播图Id
 * @returns
 */
export function delZoneImage(params) {
  return request({
    url: '/page/delZoneImage/',
    method: 'get',
    params
  })
}
/**
 * 专区轮播图排序
 * @param {*} imageId 专区Id
 * @param {*} sort 排序值
 * @returns
 */
export function updateImageSort(params) {
  return request({
    url: '/page/updateImageSort',
    method: 'get',
    params
  })
}
/**
 * 专区轮播图状态更新
 * @param {*} imageId 专区Id
 * @param {*} status 0停用 1启用
 * @param {*} type  0www 1小程序
 * @returns
 */
export function updateImageStatus(params) {
  return request({
    url: '/page/updateImageStatus',
    method: 'get',
    params
  })
}
/**
 * 专区轮播图编辑回显
 * @param {*} imageId 轮播Id
 * @returns
 */
export function getZoneImageById(params) {
  return request({
    url: '/page/zoneImageForm',
    method: 'get',
    params
  })
}
/**
 * 获取首页推荐商品列表
 * @param {*} productId 商品Id
 * @param {*} shopName 供应商名称
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function getRecommendList(params) {
  return request({
    url: '/page/recommendList',
    method: 'get',
    params
  })
}
/**
 * 删除推荐商品
 * @param {*} ids 商品Id逗号拼接
 * @returns
 */
export function delRecommendProduct(params) {
  return request({
    url: '/page/recommendDel',
    method: 'get',
    params
  })
}
/**
 * 保存推荐商品
 * @param {*} ids 商品Id逗号拼接
 * @returns
 */
export function addRecommendProduct(params) {
  return request({
    url: '/page/addRecommendProduct',
    method: 'get',
    params
  })
}
/**
 * 专区商品排序
 * @param {*} productId 商品Id
 * @param {*} sort 排序值
 * @returns
 */
export function updateRecommendSort(params) {
  return request({
    url: '/page/recommendSort',
    method: 'get',
    params
  })
}
/**
 * 获取首页专属广告图列表
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function getTopAdvertisement(params) {
  return request({
    url: '/page/topAdvertisement/list',
    method: 'get',
    params
  })
}
/**
 * 专属广告图保存
 * @param {*} id 广告图Id
 * @param {*} title PC标题
 * @param {*} crmTitle 小程序标题
 * @param {*} image WWW图片
 * @param {*} crmImage 小程序图片
 * @param {*} link WWW跳转链接
 * @param {*} crmLink 小程序跳转链接
 * @param {*} wwwEnabledStatus Pc端状态 0停用 1启用
 * @param {*} crmEnabledStatus 小程序端状态 0停用 1启用
 * @param {*} sort 排序
 * @returns
 */
export function saveTopAdvertisement(data) {
  return request({
    url: '/page/saveTopAdvertisement',
    method: 'post',
    data: data
  })
}
/**
 * 删除专属广告图
 * @param {*} id 广告图Id
 * @returns
 */
export function topAdvertisementDel(params) {
  return request({
    url: '/page/topAdvertisementDel',
    method: 'get',
    params
  })
}
/**
 * 专属广告图状态更新
 * @param {*} id 广告图Id
 * @param {*} status 0停用 1启用
 * @param {*} type  0www 1小程序
 * @returns
 */
export function updateTopStatus(params) {
  return request({
    url: '/page/updateTopStatus',
    method: 'get',
    params
  })
}
/**
 * 专属广告图编辑回显
 * @param {*} id 广告图Id
 * @returns
 */
export function getTopAdvertisementForm(params) {
  return request({
    url: '/page/topAdvertisement/form',
    method: 'get',
    params
  })
}
/**
 * 获取首页小广告图列表
 * @param {*} pageNum 页码
 * @param {*} pageSize 条数
 * @returns
 */
export function getAdvertisement(params) {
  return request({
    url: '/page/advertisement/list',
    method: 'get',
    params
  })
}
/**
 * 小广告图保存
 * @param {*} id 广告图Id
 * @param {*} title PC标题
 * @param {*} crmTitle 小程序标题
 * @param {*} image WWW图片
 * @param {*} crmImage 小程序图片
 * @param {*} link WWW跳转链接
 * @param {*} crmLink 小程序跳转链接
 * @param {*} wwwEnabledStatus Pc端状态 0停用 1启用
 * @param {*} crmEnabledStatus 小程序端状态 0停用 1启用
 * @param {*} sort 排序
 * @returns
 */
export function saveAdvertisement(data) {
  return request({
    url: '/page/saveAdvertisement',
    method: 'post',
    data: data
  })
}
/**
 * 删除小广告图
 * @param {*} id 广告图Id
 * @returns
 */
export function advertisementDel(params) {
  return request({
    url: '/page/advertisementDel',
    method: 'get',
    params
  })
}
/**
 * 小广告图排序
 * @param {*} id 小广告图Id
 * @param {*} sort 排序值
 * @returns
 */
export function updateAdvertisementSort(params) {
  return request({
    url: '/page/advertisement/sort',
    method: 'get',
    params
  })
}
/**
 * 小广告图状态更新
 * @param {*} id 广告图Id
 * @param {*} status 0停用 1启用
 * @param {*} type  0www 1小程序
 * @returns
 */
export function updateAdvertiStatus(params) {
  return request({
    url: '/page/updateAdvertiStatus',
    method: 'get',
    params
  })
}
/**
 * 小广告图编辑回显
 * @param {*} id 广告图Id
 * @returns
 */
export function getAdvertisementForm(params) {
  return request({
    url: '/page/advertisement/form',
    method: 'get',
    params
  })
}
