import request from '@/utils/request'
/**
 * 获取服务商列表
 * @returns
 */
export function getServiceList(params) {
  return request({
    url: '/providers/addGroups',
    method: 'get',
    params
  })
}
/**
 * 服务商团队列表
 * @returns
 */
export const getTeamList = (params) => request({
  url: '/providers/teamList',
  method: 'get',
  params
})
/**
 * 添加服务商团队
 * @param {*} name 团队名称
 * @param {*} teamId 团队ID
 * @param {*} leaderId 团队管理员ID
 * @returns
 */
export const addTeam = (data) => request({
  url: '/providers/add/team',
  method: 'post',
  data
})
/**
 * 删除团队
 * @param {*} id 团队ID
 * @returns
 */
export const delTeam = (params) => request({
  url: '/providers/del/team',
  method: 'get',
  params
})

/**
 * 团队成员列表
 * @param {*} id 团队ID
 * @returns
 */
export const groupList = (params) => request({
  url: '/providers/groupList',
  method: 'get',
  params
})
/**
 * 删除成员
 * @param {*} teamId 团队ID
 * @param {*} spId 成员ID
 * @returns
 */
export const delGroup = (params) => request({
  url: '/providers/del/group',
  method: 'get',
  params
})

/**
 * 添加成员
 * @param {*} teamId 团队ID
 * @param {*} spId 成员ID（逗号隔开）
 * @returns
 */
export const addGroup = (params) => request({
  url: '/providers/add/group',
  method: 'get',
  params
})

/**
 * 设置团队管理员
 * @param {*} teamId 团队ID
 * @param {*} leaderId 组长ID
 * @returns
 */
export const updateLeader = (data) => request({
  url: '/providers/update/leader',
  method: 'post',
  data
})

